@@ -20,6 +20,7 @@ from __future__ import print_function
 
 import sys
 import getopt
+import json
 import logging
 import traceback
 import pprint
@@ -31,6 +32,7 @@ import pyipmi
 import pyipmi.interfaces
 from pyipmi.utils import py3_array_tobytes
 
+json_output = False
 
 Command = namedtuple('Command', 'name fn')
 CommandHelp = namedtuple('CommandHelp', 'name arguments help')
@@ -329,7 +331,21 @@ def cmd_hpm_install(ipmi, args):
 
 def cmd_chassis_status(ipmi, args):
     status = ipmi.get_chassis_status()
-    print('''
+
+    if json_output:
+        status = {
+                  'power_on': status.power_on,
+                  'overload': status.overload,
+                  'interlock': status.interlock,
+                  'fault': status.fault,
+                  'ctrl_fault': status.control_fault,
+                  'restore_policy': status.restore_policy
+                 }
+        print(json.dumps(status))
+        pass
+    else:
+
+        print('''
 Power ON:          %(power_on)s
 Overload:          %(overload)s
 Interlock:         %(interlock)s
@@ -338,10 +354,10 @@ Ctrl Fault:        %(control_fault)s
 Restore Policy:    %(restore_policy)s
 '''[1:-1] % status.__dict__)
 
-    for event in status.last_event:
-        print(event)
-    for state in status.chassis_state:
-        print(state)
+        for event in status.last_event:
+            print(event)
+        for state in status.chassis_state:
+            print(state)
 
 
 def cmd_picmg_get_power(ipmi, args):
@@ -458,6 +474,7 @@ Options:
   -I <interface>   Set interface (available: rmcp, aardvark, ipmitool, ipmbdev)
   -H <host>        Set RMCP host
   -U <user>        Set RMCP user
+  -L <level>       Set RMCP priviledge level
   -P <password>    Set RMCP password
   -o <options>     Set interface specific options (name=value, separated
                    by commas, see below for available options).
@@ -467,6 +484,7 @@ Aardvark interface options:
   serial=<SN>       Serial number of the device
   pullups=<on|off>  Enable/disable pullups
   power=<on|off>    Enable/disable target power
+  fastmode=<on|off> Enable/disable 400kHz I2C bitrate (Default 100kHz)
 
 Ipmitool interface options:
   interface_type    Set the interface type to be used (lan, lanplus, serial, open)
@@ -506,6 +524,10 @@ def parse_interface_options(interface_name, options):
                 interface_options['enable_target_power'] = True
             elif (name, value) == ('power', 'off'):
                 interface_options['enable_target_power'] = False
+            elif (name, value) == ('fastmode', 'on'):
+                interface_options['enable_fastmode'] = True
+            elif (name, value) == ('fastmode', 'off'):
+                interface_options['enable_fastmode'] = False
             else:
                 print('Warning: unknown option %s' % name)
         elif interface_name == 'ipmitool':
@@ -522,7 +544,7 @@ def parse_interface_options(interface_name, options):
 
 def main():
     try:
-        opts, args = getopt.getopt(sys.argv[1:], 't:hvVI:H:U:P:o:b:p:r:')
+        opts, args = getopt.getopt(sys.argv[1:], 't:hvVI:H:U:P:L:o:b:p:r:J')
     except getopt.GetoptError as err:
         print(str(err))
         usage()
@@ -535,6 +557,7 @@ def main():
     rmcp_port = 623
     rmcp_user = ''
     rmcp_password = ''
+    rmcp_priv_level = None
     interface_options = list()
     for o, a in opts:
         if o == '-v':
@@ -559,10 +582,15 @@ def main():
             rmcp_user = a
         elif o == '-P':
             rmcp_password = a
+        elif o == '-L':
+            rmcp_priv_level = a
         elif o == '-I':
             interface_name = a
         elif o == '-o':
             interface_options = a
+        elif o == '-J':
+            global json_output
+            json_output = True
         else:
             assert False, 'unhandled option'
 
@@ -609,6 +637,10 @@ def main():
     if rmcp_host is not None:
         ipmi.session.set_session_type_rmcp(rmcp_host, rmcp_port)
         ipmi.session.set_auth_type_user(rmcp_user, rmcp_password)
+
+        if rmcp_priv_level is not None:
+            ipmi.session.set_priv_level(rmcp_priv_level)
+
         ipmi.session.establish()
 
     try:
